import json
from dapu.backend import query_local as query_llm

def resolve(name, goal, constraint, memory):
    system = "Reply only with JSON: {\"state\": \"value\", \"reason\": \"why\"}"
    user = f"Goal: {goal}. Constraint: {constraint}. Memory: {memory}. What is your state?"
    raw = query_llm(system, user)
    try:
        raw = raw.strip().replace("```json","").replace("```","").strip()
        return json.loads(raw)
    except:
        return {"state": raw, "reason": "ok"}

def choose_path(name, state, incentive):
    system = "Reply only with JSON: {\"choice\": \"chosen_path\", \"reason\": \"why\"}"
    user = f"Agent: {name}. Current state: {state}. Incentive rule: {incentive}. Which path do you choose?"
    raw = query_llm(system, user)
    try:
        raw = raw.strip().replace("```json","").replace("```","").strip()
        return json.loads(raw)
    except:
        return {"choice": raw, "reason": "ok"}

def negotiate(a, b):
    system = "Reply only with JSON: {\"agreed\": \"value\", \"reason\": \"why\"}"
    user = f"Agent A {a['name']} state: {a['state']}. Agent B {b['name']} state: {b['state']}. Find one agreed value."
    raw = query_llm(system, user)
    try:
        raw = raw.strip().replace("```json","").replace("```","").strip()
        return json.loads(raw)
    except:
        return {"agreed": raw, "reason": "ok"}



import sys, json, os, re
from ace2ryahee.dapu.agent import resolve, negotiate, choose_path

MEMORY_FILE = os.path.expanduser("~/.dapu_memory.json")

def load_memory():
    if os.path.exists(MEMORY_FILE):
        return json.load(open(MEMORY_FILE))
    return {}

def save_memory(mem):
    json.dump(mem, open(MEMORY_FILE, "w"), indent=2)

def parse(source):
    agents = []
    for m in re.finditer(r'agent\s+(\w+)\s*\{([^}]*)\}', source):
        name = m.group(1)
        body = m.group(2)
        a = {"name": name, "goal": "", "constraint": "", "memory": "", "incentive": ""}
        for line in body.splitlines():
            if ":" in line:
                k, _, v = line.partition(":")
                k, v = k.strip(), v.strip()
                if k in a:
                    a[k] = v
        agents.append(a)
    return agents

def run(filepath):
    memory = load_memory()
    source = open(filepath).read()
    agents = parse(source)
    print(f"[Dapu] Loaded {len(agents)} agents\n")
    states = []
    for a in agents:
        if a['name'] in memory:
            a['memory'] = f"last state was {memory[a['name']]['state']}"
            print(f"[{a['name']}] recalled: {a['memory']}")
        print(f"Resolving {a['name']}...")
        r = resolve(a['name'], a['goal'], a['constraint'], a['memory'])
        a['state'] = r['state']
        memory[a['name']] = r
        print(f"  state -> {r}")
        if a['incentive']:
            print(f"  choosing path...")
            p = choose_path(a['name'], a['state'], a['incentive'])
            a['choice'] = p['choice']
            memory[a['name']]['choice'] = p['choice']
            print(f"  path  -> {p}")
        print()
        states.append(a)
    if len(states) >= 2:
        print("Negotiating...")
        result = negotiate(states[0], states[1])
        print(f"  Agreed: {result}")
        memory['_last_negotiation'] = result
    save_memory(memory)
    print("[Dapu] Memory saved.")

if __name__ == "__main__":
    run(sys.argv[1])
def main():
    # This is the entry point that setup.py is looking for
    # Add your logic here, for example:
    if len(sys.argv) > 1:
        file_path = sys.argv[1]
        print(f"Processing file: {file_path}")
        # Call your parse logic here:
        # data = parse(open(file_path).read())
        # print(data)
    else:
        print("Please provide a file path.")

if __name__ == "__main__":
    main()



import os, json, urllib.request

GEMINI_URL = "https://generativelanguage.googleapis.com/v1beta/models/gemini-2.0-flash-lite:generateContent"

def query_llm(prompt):
    key = os.environ.get("GEMINI_API_KEY", "")
    url = GEMINI_URL + "?key=" + key
    payload = {"contents": [{"parts": [{"text": prompt}]}]}
    data = json.dumps(payload).encode()
    req = urllib.request.Request(url, data=data, headers={"Content-Type": "application/json"})
    with urllib.request.urlopen(req, timeout=30) as r:
        res = json.loads(r.read())
    return res["candidates"][0]["content"]["parts"][0]["text"]



import json
import urllib.request

LOCAL_URL = "http://127.0.0.1:8080/v1/chat/completions"

def query_local(system, user):
    payload = {
        "model": "local",
        "temperature": 0.0,
        "messages": [
            {"role": "system", "content": system},
            {"role": "user", "content": user}
        ]
    }
    data = json.dumps(payload).encode()
    req = urllib.request.Request(LOCAL_URL, data=data, headers={"Content-Type": "application/json"})
    with urllib.request.urlopen(req, timeout=180) as r:
        res = json.loads(r.read())
        return res['choices'][0]['message']['content']




from setuptools import setup, find_packages

setup(
    name="ace2ryahee",
    version="1.1.1",  # Increment version
    packages=find_packages(), # This automatically finds 'dapu' as a sub-package
    entry_points={
        "console_scripts": [
            "ace2ryahee=ace2ryahee.main:main",
        ],
    },
)




import sys, json, os, re
from agent import resolve, negotiate, choose_path

MEMORY_FILE = "memory.json"

def load_memory():
    if os.path.exists(MEMORY_FILE):
        return json.load(open(MEMORY_FILE))
    return {}

def save_memory(mem):
    json.dump(mem, open(MEMORY_FILE, "w"), indent=2)

def parse(source):
    agents = []
    for m in re.finditer(r'agent\s+(\w+)\s*\{([^}]*)\}', source):
        name = m.group(1)
        body = m.group(2)
        a = {"name": name, "goal": "", "constraint": "", "memory": "", "incentive": ""}
        for line in body.splitlines():
            if ":" in line:
                k, _, v = line.partition(":")
                k, v = k.strip(), v.strip()
                if k in a:
                    a[k] = v
        agents.append(a)
    return agents

memory = load_memory()
source = open(sys.argv[1]).read()
agents = parse(source)
print(f"Loaded {len(agents)} agents\n")

states = []
for a in agents:
    if a['name'] in memory:
        a['memory'] = f"last state was {memory[a['name']]['state']}"
        print(f"[{a['name']}] recalled: {a['memory']}")
    print(f"Resolving {a['name']}...")
    r = resolve(a['name'], a['goal'], a['constraint'], a['memory'])
    a['state'] = r['state']
    memory[a['name']] = r
    print(f"  state -> {r}")
    if a['incentive']:
        print(f"  choosing path...")
        p = choose_path(a['name'], a['state'], a['incentive'])
        a['choice'] = p['choice']
        memory[a['name']]['choice'] = p['choice']
        print(f"  path  -> {p}")
    print()
    states.append(a)

if len(states) >= 2:
    print("Negotiating...")
    result = negotiate(states[0], states[1])
    print(f"  Agreed: {result}")
    memory['_last_negotiation'] = result

save_memory(memory)
print("\nMemory saved.")
